/* This file contains the CSS data for all popups in TinyMCE */

body {
	background-color: #F0F0EE;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 11px;
	scrollbar-3dlight-color: #F0F0EE;
	scrollbar-arrow-color: #676662;
	scrollbar-base-color: #F0F0EE;
	scrollbar-darkshadow-color: #DDDDDD;
	scrollbar-face-color: #E0E0DD;
	scrollbar-highlight-color: #F0F0EE;
	scrollbar-shadow-color: #F0F0EE;
	scrollbar-track-color: #F5F5F5;
	margin: 8px;
}

td {
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 11px;
}

input {
	background: #FFFFFF;
	border: 1px solid #cccccc;
}

td, input, select, textarea {
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 10px;
}

input, select, textarea {
	border: 1px solid #808080;
}

.input_noborder {
	border: 0;
}

#insert, .updateButton {
   font-weight: bold;
   width: 90px;
   height: 21px;
   border: 0;
   background-image: url('../images/insert_button_bg.gif');
   cursor: pointer;
}

#cancel {
   font-weight: bold;
   width: 90px;
   height: 21px;
   border: 0;
   background-image: url('../images/cancel_button_bg.gif');
   cursor: pointer;
}

/* Mozilla only style */
html>body #insert, html>body #cancel {
	padding-bottom: 2px;
}

.title {
	font-size: 12px;
	font-weight: bold;
	color: #2B6FB6;
}

table.charmap {
	border-style: solid;
	border-width: 1px;
	border-color: #AAAAAA;
}

td.charmap, td.charmapOver {
	color: #000000;
	border-color: #AAAAAA;
	border-style: solid;
	border-width: 1px;
	text-align: center;
	font-size: 12px;
}

td.charmapOver {
	background-color: #CCCCCC;
	cursor: default;
}

a.charmap {
	color: #000000;
	text-decoration: none
}

.wordWrapCode {
	vertical-align: middle;
	border: 1px none #000000;
	background-color: transparent;
}

input.radio {
	border: 1px none #000000;
	background-color: transparent;
	vertical-align: middle;
}

input.checkbox {
	border: 1px none #000000;
	background-color: transparent;
	vertical-align: middle;
}

.mceButtonNormal, .mceButtonOver, .mceButtonDown, .mceSeparator, .mceButtonDisabled, .mceButtonSelected {
	margin-left: 1px;
}

.mceButtonNormal {
	border-top: 1px solid;
	border-left: 1px solid;
	border-bottom: 1px solid;
	border-right: 1px solid;
	border-color: #F0F0EE;
	cursor: default;
}

.mceButtonOver {
	border: 1px solid #0A246A;
	cursor: default;
	background-color: #B6BDD2;
}

.mceButtonDown {
	cursor: default;
	border: 1px solid #0A246A;
	background-color: #8592B5;
}

.mceButtonDisabled {
	filter:progid:DXImageTransform.Microsoft.Alpha(opacity=30);
	-moz-opacity:0.3;
	opacity: 0.3;
	border-top: 1px solid;
	border-left: 1px solid;
	border-bottom: 1px solid;
	border-right: 1px solid;
	border-color: #F0F0EE;
	cursor: default;
}

.mceActionPanel {
	margin-top: 5px;
}

/* Tabs classes */

.tabs {
	float: left;
	width: 100%;
	line-height: normal;
	background-image: url("../images/xp/tabs_bg.gif");
}

.tabs ul {
	margin: 0;
	padding: 0 0 0;
	list-style: none;
}

.tabs li {
	float: left;
	background: url("../images/xp/tab_bg.gif") no-repeat left top;
	margin: 0;
	margin-left: 0;
	margin-right: 2px;
	padding: 0 0 0 10px;
	line-height: 18px;
}

.tabs li.current {
	background: url("../images/xp/tab_sel_bg.gif") no-repeat left top;
	margin-right: 2px;
}

.tabs span {
	float: left;
	display: block;
	background: url("../images/xp/tab_end.gif") no-repeat right top;
	padding: 0px 10px 0 0;
}

.tabs .current span {
	background: url("../images/xp/tab_sel_end.gif") no-repeat right top;
}

.tabs a {
	text-decoration: none;
	font-family: Verdana, Arial;
	font-size: 10px;
}

.tabs a:link, .tabs a:visited, .tabs a:hover {
	color: black;
}

.tabs a:hover {
}

.tabs .current {
}

.tabs .current a, .tabs .current a:link, .tabs .current a:visited {
}

.panel_wrapper div.panel {
	display: none;
}

.panel_wrapper div.current {
	display: block;
	width: 100%;
	height: 300px;
	overflow: visible; /* Should be auto but that breaks Safari */
}

.panel_wrapper {
	border: 1px solid #919B9C;
	border-top: 0px;
	padding: 10px;
	padding-top: 5px;
	clear: both;
	background-color: white;
}

fieldset {
	border: 1px solid #919B9C;
	font-family: Verdana, Arial;
	font-size: 10px;
	padding: 0;
	margin: 0;
	padding: 4px;
}

legend {
	color: #2B6FB6;
	font-weight: bold;
}

.properties {
	width: 100%;
}

.properties .column1 {
}

.properties .column2 {
	text-align: left;
}

a:link, a:visited {
	color: black;
}

a:hover {
	color: #2B6FB6;
}

#plugintable thead {
	font-weight: bold;
	background-color: #DDDDDD;
}

#plugintable, #about #plugintable td {
	border: 1px solid #919B9C;
}

#plugintable {
	width: 99%;
	margin-top: 10px;
}

#pluginscontainer {
	height: 290px;
	overflow: auto;
}

/* MSIE Specific styles */

* html .panel_wrapper {
	width: 100%;
}

.column {
	float: left;
}

h1, h2, h3, h4 {
	color: #2B6FB6;
	margin: 0;
	padding: 0;
	padding-top: 5px;
}

h3 {
	font-size: 14px;
}

#link .panel_wrapper, #link div.current {
	height: 125px;
}

#image .panel_wrapper, #image div.current {
	height: 190px;
}

/* Disables the advanced tab in the table plugin. */
/*
#table #advanced_tab {
	display: none;
}
*/

/* Disables the border input field and label in the table plugin. */
/*
#table #border, #table #borderlabel {
	display: none;
}
*/
