/* This is the CSS file for the noneditable elements plugin */

.mceEditable {
	/*border: 1px dotted #0000cc;*/
	-moz-user-focus: none;
	-moz-user-input: auto;
	-moz-user-modify: auto;
	-moz-user-select: text;
}

.mceNonEditable {
	/*border: 1px dotted #cc0000;*/
	-moz-user-focus: ignore;
	/*-moz-user-input: disabled;*/
	-moz-user-modify: read-only;
	-moz-user-select: all;
}
